==> vtk6-6.3.0-5-armv6h.pkg.tar.xz: vtk/vtkExtractTensorComponents.java <==
// java wrapper for vtkExtractTensorComponents object
//

package vtk;
import vtk.*;

public class vtkExtractTensorComponents extends vtkDataSetAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetPassTensorsToOutput_2(int id0);
  public void SetPassTensorsToOutput(int id0)
    { SetPassTensorsToOutput_2(id0); }

  private native int GetPassTensorsToOutput_3();
  public int GetPassTensorsToOutput()
    { return GetPassTensorsToOutput_3(); }

  private native void PassTensorsToOutputOn_4();
  public void PassTensorsToOutputOn()
    { PassTensorsToOutputOn_4(); }

  private native void PassTensorsToOutputOff_5();
  public void PassTensorsToOutputOff()
    { PassTensorsToOutputOff_5(); }

  private native void SetExtractScalars_6(int id0);
  public void SetExtractScalars(int id0)
    { SetExtractScalars_6(id0); }

  private native int GetExtractScalars_7();
  public int GetExtractScalars()
    { return GetExtractScalars_7(); }

  private native void ExtractScalarsOn_8();
  public void ExtractScalarsOn()
    { ExtractScalarsOn_8(); }

  private native void ExtractScalarsOff_9();
  public void ExtractScalarsOff()
    { ExtractScalarsOff_9(); }

  private native void SetScalarComponents_10(int id0,int id1);
  public void SetScalarComponents(int id0,int id1)
    { SetScalarComponents_10(id0,id1); }

  private native void SetScalarComponents_11(int id0[]);
  public void SetScalarComponents(int id0[])
    { SetScalarComponents_11(id0); }

  private native int[]  GetScalarComponents_12();
  public int[]  GetScalarComponents()
    { return GetScalarComponents_12(); }

  private native void SetScalarMode_13(int id0);
  public void SetScalarMode(int id0)
    { SetScalarMode_13(id0); }

  private native int GetScalarMode_14();
  public int GetScalarMode()
    { return GetScalarMode_14(); }

  private native void SetScalarModeToComponent_15();
  public void SetScalarModeToComponent()
    { SetScalarModeToComponent_15(); }

  private native void SetScalarModeToEffectiveStress_16();
  public void SetScalarModeToEffectiveStress()
    { SetScalarModeToEffectiveStress_16(); }

  private native void SetScalarModeToDeterminant_17();
  public void SetScalarModeToDeterminant()
    { SetScalarModeToDeterminant_17(); }

  private native void ScalarIsComponent_18();
  public void ScalarIsComponent()
    { ScalarIsComponent_18(); }

  private native void ScalarIsEffectiveStress_19();
  public void ScalarIsEffectiveStress()
    { ScalarIsEffectiveStress_19(); }

  private native void ScalarIsDeterminant_20();
  public void ScalarIsDeterminant()
    { ScalarIsDeterminant_20(); }

  private native void SetExtractVectors_21(int id0);
  public void SetExtractVectors(int id0)
    { SetExtractVectors_21(id0); }

  private native int GetExtractVectors_22();
  public int GetExtractVectors()
    { return GetExtractVectors_22(); }

  private native void ExtractVectorsOn_23();
  public void ExtractVectorsOn()
    { ExtractVectorsOn_23(); }

  private native void ExtractVectorsOff_24();
  public void ExtractVectorsOff()
    { ExtractVectorsOff_24(); }

  private native void SetVectorComponents_25(int id0,int id1,int id2,int id3,int id4,int id5);
  public void SetVectorComponents(int id0,int id1,int id2,int id3,int id4,int id5)
    { SetVectorComponents_25(id0,id1,id2,id3,id4,id5); }

  private native void SetVectorComponents_26(int id0[]);
  public void SetVectorComponents(int id0[])
    { SetVectorComponents_26(id0); }

  private native int[]  GetVectorComponents_27();
  public int[]  GetVectorComponents()
    { return GetVectorComponents_27(); }

  private native void SetExtractNormals_28(int id0);
  public void SetExtractNormals(int id0)
    { SetExtractNormals_28(id0); }

  private native int GetExtractNormals_29();
  public int GetExtractNormals()
    { return GetExtractNormals_29(); }

  private native void ExtractNormalsOn_30();
  public void ExtractNormalsOn()
    { ExtractNormalsOn_30(); }

  private native void ExtractNormalsOff_31();
  public void ExtractNormalsOff()
    { ExtractNormalsOff_31(); }

  private native void SetNormalizeNormals_32(int id0);
  public void SetNormalizeNormals(int id0)
    { SetNormalizeNormals_32(id0); }

  private native int GetNormalizeNormals_33();
  public int GetNormalizeNormals()
    { return GetNormalizeNormals_33(); }

  private native void NormalizeNormalsOn_34();
  public void NormalizeNormalsOn()
    { NormalizeNormalsOn_34(); }

  private native void NormalizeNormalsOff_35();
  public void NormalizeNormalsOff()
    { NormalizeNormalsOff_35(); }

  private native void SetNormalComponents_36(int id0,int id1,int id2,int id3,int id4,int id5);
  public void SetNormalComponents(int id0,int id1,int id2,int id3,int id4,int id5)
    { SetNormalComponents_36(id0,id1,id2,id3,id4,id5); }

  private native void SetNormalComponents_37(int id0[]);
  public void SetNormalComponents(int id0[])
    { SetNormalComponents_37(id0); }

  private native int[]  GetNormalComponents_38();
  public int[]  GetNormalComponents()
    { return GetNormalComponents_38(); }

  private native void SetExtractTCoords_39(int id0);
  public void SetExtractTCoords(int id0)
    { SetExtractTCoords_39(id0); }

  private native int GetExtractTCoords_40();
  public int GetExtractTCoords()
    { return GetExtractTCoords_40(); }

  private native void ExtractTCoordsOn_41();
  public void ExtractTCoordsOn()
    { ExtractTCoordsOn_41(); }

  private native void ExtractTCoordsOff_42();
  public void ExtractTCoordsOff()
    { ExtractTCoordsOff_42(); }

  private native void SetNumberOfTCoords_43(int id0);
  public void SetNumberOfTCoords(int id0)
    { SetNumberOfTCoords_43(id0); }

  private native int GetNumberOfTCoordsMinValue_44();
  public int GetNumberOfTCoordsMinValue()
    { return GetNumberOfTCoordsMinValue_44(); }

  private native int GetNumberOfTCoordsMaxValue_45();
  public int GetNumberOfTCoordsMaxValue()
    { return GetNumberOfTCoordsMaxValue_45(); }

  private native int GetNumberOfTCoords_46();
  public int GetNumberOfTCoords()
    { return GetNumberOfTCoords_46(); }

  private native void SetTCoordComponents_47(int id0,int id1,int id2,int id3,int id4,int id5);
  public void SetTCoordComponents(int id0,int id1,int id2,int id3,int id4,int id5)
    { SetTCoordComponents_47(id0,id1,id2,id3,id4,id5); }

  private native void SetTCoordComponents_48(int id0[]);
  public void SetTCoordComponents(int id0[])
    { SetTCoordComponents_48(id0); }

  private native int[]  GetTCoordComponents_49();
  public int[]  GetTCoordComponents()
    { return GetTCoordComponents_49(); }

  public vtkExtractTensorComponents() { super(); }

  public vtkExtractTensorComponents(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.0.1-2-armv6h.pkg.tar.xz: vtk/vtkExtractTensorComponents.java <==
// java wrapper for vtkExtractTensorComponents object
//

package vtk;
import vtk.*;

public class vtkExtractTensorComponents extends vtkDataSetAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetPassTensorsToOutput_2(int id0);
  public void SetPassTensorsToOutput(int id0)
    { SetPassTensorsToOutput_2(id0); }

  private native int GetPassTensorsToOutput_3();
  public int GetPassTensorsToOutput()
    { return GetPassTensorsToOutput_3(); }

  private native void PassTensorsToOutputOn_4();
  public void PassTensorsToOutputOn()
    { PassTensorsToOutputOn_4(); }

  private native void PassTensorsToOutputOff_5();
  public void PassTensorsToOutputOff()
    { PassTensorsToOutputOff_5(); }

  private native void SetExtractScalars_6(int id0);
  public void SetExtractScalars(int id0)
    { SetExtractScalars_6(id0); }

  private native int GetExtractScalars_7();
  public int GetExtractScalars()
    { return GetExtractScalars_7(); }

  private native void ExtractScalarsOn_8();
  public void ExtractScalarsOn()
    { ExtractScalarsOn_8(); }

  private native void ExtractScalarsOff_9();
  public void ExtractScalarsOff()
    { ExtractScalarsOff_9(); }

  private native void SetScalarComponents_10(int id0,int id1);
  public void SetScalarComponents(int id0,int id1)
    { SetScalarComponents_10(id0,id1); }

  private native void SetScalarComponents_11(int id0[]);
  public void SetScalarComponents(int id0[])
    { SetScalarComponents_11(id0); }

  private native int[]  GetScalarComponents_12();
  public int[]  GetScalarComponents()
    { return GetScalarComponents_12(); }

  private native void SetScalarMode_13(int id0);
  public void SetScalarMode(int id0)
    { SetScalarMode_13(id0); }

  private native int GetScalarMode_14();
  public int GetScalarMode()
    { return GetScalarMode_14(); }

  private native void SetScalarModeToComponent_15();
  public void SetScalarModeToComponent()
    { SetScalarModeToComponent_15(); }

  private native void SetScalarModeToEffectiveStress_16();
  public void SetScalarModeToEffectiveStress()
    { SetScalarModeToEffectiveStress_16(); }

  private native void SetScalarModeToDeterminant_17();
  public void SetScalarModeToDeterminant()
    { SetScalarModeToDeterminant_17(); }

  private native void ScalarIsComponent_18();
  public void ScalarIsComponent()
    { ScalarIsComponent_18(); }

  private native void ScalarIsEffectiveStress_19();
  public void ScalarIsEffectiveStress()
    { ScalarIsEffectiveStress_19(); }

  private native void ScalarIsDeterminant_20();
  public void ScalarIsDeterminant()
    { ScalarIsDeterminant_20(); }

  private native void SetExtractVectors_21(int id0);
  public void SetExtractVectors(int id0)
    { SetExtractVectors_21(id0); }

  private native int GetExtractVectors_22();
  public int GetExtractVectors()
    { return GetExtractVectors_22(); }

  private native void ExtractVectorsOn_23();
  public void ExtractVectorsOn()
    { ExtractVectorsOn_23(); }

  private native void ExtractVectorsOff_24();
  public void ExtractVectorsOff()
    { ExtractVectorsOff_24(); }

  private native void SetVectorComponents_25(int id0,int id1,int id2,int id3,int id4,int id5);
  public void SetVectorComponents(int id0,int id1,int id2,int id3,int id4,int id5)
    { SetVectorComponents_25(id0,id1,id2,id3,id4,id5); }

  private native void SetVectorComponents_26(int id0[]);
  public void SetVectorComponents(int id0[])
    { SetVectorComponents_26(id0); }

  private native int[]  GetVectorComponents_27();
  public int[]  GetVectorComponents()
    { return GetVectorComponents_27(); }

  private native void SetExtractNormals_28(int id0);
  public void SetExtractNormals(int id0)
    { SetExtractNormals_28(id0); }

  private native int GetExtractNormals_29();
  public int GetExtractNormals()
    { return GetExtractNormals_29(); }

  private native void ExtractNormalsOn_30();
  public void ExtractNormalsOn()
    { ExtractNormalsOn_30(); }

  private native void ExtractNormalsOff_31();
  public void ExtractNormalsOff()
    { ExtractNormalsOff_31(); }

  private native void SetNormalizeNormals_32(int id0);
  public void SetNormalizeNormals(int id0)
    { SetNormalizeNormals_32(id0); }

  private native int GetNormalizeNormals_33();
  public int GetNormalizeNormals()
    { return GetNormalizeNormals_33(); }

  private native void NormalizeNormalsOn_34();
  public void NormalizeNormalsOn()
    { NormalizeNormalsOn_34(); }

  private native void NormalizeNormalsOff_35();
  public void NormalizeNormalsOff()
    { NormalizeNormalsOff_35(); }

  private native void SetNormalComponents_36(int id0,int id1,int id2,int id3,int id4,int id5);
  public void SetNormalComponents(int id0,int id1,int id2,int id3,int id4,int id5)
    { SetNormalComponents_36(id0,id1,id2,id3,id4,id5); }

  private native void SetNormalComponents_37(int id0[]);
  public void SetNormalComponents(int id0[])
    { SetNormalComponents_37(id0); }

  private native int[]  GetNormalComponents_38();
  public int[]  GetNormalComponents()
    { return GetNormalComponents_38(); }

  private native void SetExtractTCoords_39(int id0);
  public void SetExtractTCoords(int id0)
    { SetExtractTCoords_39(id0); }

  private native int GetExtractTCoords_40();
  public int GetExtractTCoords()
    { return GetExtractTCoords_40(); }

  private native void ExtractTCoordsOn_41();
  public void ExtractTCoordsOn()
    { ExtractTCoordsOn_41(); }

  private native void ExtractTCoordsOff_42();
  public void ExtractTCoordsOff()
    { ExtractTCoordsOff_42(); }

  private native void SetNumberOfTCoords_43(int id0);
  public void SetNumberOfTCoords(int id0)
    { SetNumberOfTCoords_43(id0); }

  private native int GetNumberOfTCoordsMinValue_44();
  public int GetNumberOfTCoordsMinValue()
    { return GetNumberOfTCoordsMinValue_44(); }

  private native int GetNumberOfTCoordsMaxValue_45();
  public int GetNumberOfTCoordsMaxValue()
    { return GetNumberOfTCoordsMaxValue_45(); }

  private native int GetNumberOfTCoords_46();
  public int GetNumberOfTCoords()
    { return GetNumberOfTCoords_46(); }

  private native void SetTCoordComponents_47(int id0,int id1,int id2,int id3,int id4,int id5);
  public void SetTCoordComponents(int id0,int id1,int id2,int id3,int id4,int id5)
    { SetTCoordComponents_47(id0,id1,id2,id3,id4,id5); }

  private native void SetTCoordComponents_48(int id0[]);
  public void SetTCoordComponents(int id0[])
    { SetTCoordComponents_48(id0); }

  private native int[]  GetTCoordComponents_49();
  public int[]  GetTCoordComponents()
    { return GetTCoordComponents_49(); }

  public vtkExtractTensorComponents() { super(); }

  public vtkExtractTensorComponents(long id) { super(id); }
  public native long   VTKInit();

}
